@@ -1,6 +1,9 @@
 package Prty;
 
-our $VERSION = 1.082;
+use strict;
+use warnings;
+
+our $VERSION = 1.083;
 
 =encoding utf8
 
@@ -492,11 +495,15 @@ L<Prty::TextFile::Line> - Zeile einer Textdatei
 
 L<Prty::Udl> - Universal Database Locator
 
+=item *
+
+L<Prty::Unindent> - Entferne Einrückung von "Here Document" oder String-Literal
+
 =back
 
 =head1 VERSION
 
-1.082
+1.083
 
 =head1 AUTHOR
 
