@@ -5,8 +5,9 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.082;
+our $VERSION = 1.083;
 
+use Prty::Unindent;
 use Prty::Storable;
 use Prty::Html::Widget::Hidden;
 use Prty::Html::Table::Simple;
@@ -160,6 +161,217 @@ sub new {
 
 # -----------------------------------------------------------------------------
 
+=head2 Klassenmethoden
+
+=head3 pluginCode() - JavaScript-Code des Plugin
+
+=head4 Synopsis
+
+    $javascript = $e->pluginCode;
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub pluginCode {
+    my $this = shift;
+
+    return Prty::Unindent->hereDoc(q~
+    $.widget('prty.inheritanceForm',{
+        options: {
+            parentData: false,
+            childData: false,
+            saveAction: null,
+            deleteAction: null,
+        },
+        _create: function () {
+            this.element.addClass('inheritanceForm');
+
+            this._on(this.element,{
+                'click .editCheckBox': function (event) {
+                    this.__render();
+                },
+                'click .saveButton': function (event) {
+                    this.__save();
+                },
+                'click .copyButton': function (event) {
+                    this.__copy();
+                },
+                'click .deleteButton': function (event) {
+                    this.__delete();
+                },
+            });
+
+            this.__render()
+        },
+        __save: function () {
+            // Prüfe, ob das Formular Daten enthält
+
+            var dataFound = 0;
+            $('.childTable :input',this.element).each(function () {
+                var name = this.name;
+                var val = $(this).val();
+                if (val != '') {
+                    dataFound++;
+                }
+            });
+            if (!dataFound) {
+                alert('Bitte füllen Sie das Formular aus');
+                return;
+            }
+
+            var instance = this;
+            var url = this.options.saveAction;
+            var data = $(':input',this.element).serialize();
+
+            $.ajax({
+                url: url,
+                type: 'POST',
+                data: data,
+                async: false,
+                success: function () {
+                    instance.options.childData = true;
+                    $('.editCheckBox',instance.element)
+                        .prop('checked',false);
+                    instance.__render();
+                },
+                error: function () {
+                    alert('FEHLER: Speichern fehlgeschlagen');
+                },
+            });
+        },
+        __clear: function () {
+            // Child-Formular Feldinhalte löschen
+            $('.childTable :input',this.element).each(function () {
+                var $this = $(this);
+                if ($this.is(':radio,:checkbox')) {
+                    $this.prop('checked',false);
+                }
+                else {
+                    $this.val('');
+                }
+            });
+        },
+        __copy: function () {
+            var $parentInputs = $('.parentTable :input',this.element);
+            var $childInputs = $('.childTable :input',this.element);
+            for (var i = 0; i < $parentInputs.length; i++) {
+                var $parentInput = $($parentInputs.get(i));
+                var $childInput = $($childInputs.get(i));
+                if ($parentInput.is(':radio,:checkbox')) {
+                    $childInput.prop('checked',
+                        $parentInput.prop('checked'));
+                }
+                else {
+                    $childInput.val($parentInput.val());
+                }
+            }
+            this.__enableButton('.deleteButton');
+        },
+        __delete: function () {
+            if (!this.options.childData) {
+                this.__clear();
+                this.__disableButton('.deleteButton');
+            }
+            else if (confirm('"'+this.options.title+'"'
+                    +' des Mandanten wirklich löschen?')) {
+                var instance = this;
+                var url = this.options.deleteAction;
+                var data = $(':input',this.element).serialize();
+
+                $.ajax({
+                    url: url,
+                    type: 'POST',
+                    data: data,
+                    async: false,
+                    success: function () {
+                        instance.options.childData = false;
+                        $('.editCheckBox',instance.element)
+                            .prop('checked',false);
+                        instance.__render();
+                        instance.__clear();
+                    },
+                    error: function () {
+                        alert('FEHLER: Speichern fehlgeschlagen');
+                    },
+                });
+            }
+        },
+        __enableButton: function (selector) {
+            var $button = $(selector,this.element);
+            $button.prop('disabled',false);
+            $button.removeClass('disabled');
+            $button.addClass('enabled');
+        },
+        __disableButton: function (selector) {
+            var $button = $(selector,this.element);
+            $button.prop('disabled',true);
+            $button.removeClass('enabled');
+            $button.addClass('disabled');
+        },
+        __render: function () {
+            var $parentTable = $('.parentTable',this.element);
+            var $childTable = $('.childTable',this.element);
+            var $childWidgets = $(':input',$childTable);
+            var edit = $('.editCheckBox',this.element).is(':checked');
+
+            if (edit) {
+                if (this.options.parentData) {
+                    $parentTable.show();
+                }
+                $childTable.show();
+
+                // Child-Widgets enablen
+
+                $childWidgets.prop('disabled',false);
+                $childWidgets.removeClass('disabled');
+                $childWidgets.addClass('enabled');
+
+                // Buttons enablen
+
+                if (this.options.saveAction) {
+                    this.__enableButton('.saveButton');
+                }
+
+                if (!this.options.childData) {
+                    if (this.options.parentData) {
+                        this.__enableButton('.copyButton');
+                    }
+                }
+                else if (this.options.deleteAction) {
+                    this.__enableButton('.deleteButton');
+                }
+            }
+            else { // view
+                if (this.options.parentData
+                        && !this.options.childData) {
+                    $parentTable.show();
+                    $childTable.hide();
+                }
+                else {
+                    $parentTable.hide();
+                    $childTable.show();
+                }
+
+                // Child-Widgets disablen
+
+                $childWidgets.prop('disabled',true);
+                $childWidgets.removeClass('enabled');
+                $childWidgets.addClass('disabled');
+
+                // Buttons disablen
+
+                this.__disableButton('.saveButton');
+                this.__disableButton('.copyButton');
+                this.__disableButton('.deleteButton');
+            }
+        }
+    });
+    ~);
+}
+
+# -----------------------------------------------------------------------------
+
 =head2 Objektmethoden
 
 =head3 html() - Generiere HTML
@@ -362,198 +574,7 @@ sub html {
             ),
         ),
         javaScript=>q~
-            $.widget('prty.inheritForm',{
-                options: {
-                    parentData: false,
-                    childData: false,
-                    saveAction: null,
-                    deleteAction: null,
-                },
-                _create: function () {
-                    this.element.addClass('inheritForm');
-
-                    this._on(this.element,{
-                        'click .editCheckBox': function (event) {
-                            this.__render();
-                        },
-                        'click .saveButton': function (event) {
-                            this.__save();
-                        },
-                        'click .copyButton': function (event) {
-                            this.__copy();
-                        },
-                        'click .deleteButton': function (event) {
-                            this.__delete();
-                        },
-                    });
-
-                    this.__render()
-                },
-                __save: function () {
-                    // Prüfe, ob das Formular Daten enthält
-
-                    var dataFound = 0;
-                    $('.childTable :input',this.element).each(function () {
-                        var name = this.name;
-                        var val = $(this).val();
-                        if (val != '') {
-                            dataFound++;
-                        }
-                    });
-                    if (!dataFound) {
-                        alert('Bitte füllen Sie das Formular aus');
-                        return;
-                    }
-    
-                    var instance = this;
-                    var url = this.options.saveAction;
-                    var data = $(':input',this.element).serialize();
-
-                    $.ajax({
-                        url: url,
-                        type: 'POST',
-                        data: data,
-                        async: false,
-                        success: function () {
-                            instance.options.childData = true;
-                            $('.editCheckBox',instance.element)
-                                .prop('checked',false);
-                            instance.__render();
-                        },
-                        error: function () {
-                            alert('FEHLER: Speichern fehlgeschlagen');
-                        },
-                    });
-                },
-                __clear: function () {
-                    // Child-Formular Feldinhalte löschen
-                    $('.childTable :input',this.element).each(function () {
-                        var $this = $(this);
-                        if ($this.is(':radio,:checkbox')) {
-                            $this.prop('checked',false);
-                        }
-                        else {
-                            $this.val('');
-                        }
-                    });
-                },
-                __copy: function () {
-                    var $parentInputs = $('.parentTable :input',this.element);
-                    var $childInputs = $('.childTable :input',this.element);
-                    for (var i = 0; i < $parentInputs.length; i++) {
-                        var $parentInput = $($parentInputs.get(i));
-                        var $childInput = $($childInputs.get(i));
-                        if ($parentInput.is(':radio,:checkbox')) {
-                            $childInput.prop('checked',
-                                $parentInput.prop('checked'));
-                        }
-                        else {
-                            $childInput.val($parentInput.val());
-                        }
-                    }
-                    this.__enableButton('.deleteButton');
-                },
-                __delete: function () {
-                    if (!this.options.childData) {
-                        this.__clear();
-                        this.__disableButton('.deleteButton');
-                    }
-                    else if (confirm('"'+this.options.title+'"'
-                            +' des Mandanten wirklich löschen?')) {
-                        var instance = this;
-                        var url = this.options.deleteAction;
-                        var data = $(':input',this.element).serialize();
-
-                        $.ajax({
-                            url: url,
-                            type: 'POST',
-                            data: data,
-                            async: false,
-                            success: function () {
-                                instance.options.childData = false;
-                                $('.editCheckBox',instance.element)
-                                    .prop('checked',false);
-                                instance.__render();
-                                instance.__clear();
-                            },
-                            error: function () {
-                                alert('FEHLER: Speichern fehlgeschlagen');
-                            },
-                        });
-                    }
-                },
-                __enableButton: function (selector) {
-                    var $button = $(selector,this.element);
-                    $button.prop('disabled',false);
-                    $button.removeClass('disabled');
-                    $button.addClass('enabled');
-                },
-                __disableButton: function (selector) {
-                    var $button = $(selector,this.element);
-                    $button.prop('disabled',true);
-                    $button.removeClass('enabled');
-                    $button.addClass('disabled');
-                },
-                __render: function () {
-                    var $parentTable = $('.parentTable',this.element);
-                    var $childTable = $('.childTable',this.element);
-                    var $childWidgets = $(':input',$childTable);
-                    var edit = $('.editCheckBox',this.element).is(':checked');
-    
-                    if (edit) {
-                        if (this.options.parentData) {
-                            $parentTable.show();
-                        }
-                        $childTable.show();
-
-                        // Child-Widgets enablen
-    
-                        $childWidgets.prop('disabled',false);
-                        $childWidgets.removeClass('disabled');
-                        $childWidgets.addClass('enabled');
-
-                        // Buttons enablen
-
-                        if (this.options.saveAction) {
-                            this.__enableButton('.saveButton');
-                        }
-
-                        if (!this.options.childData) {
-                            if (this.options.parentData) {
-                                this.__enableButton('.copyButton');
-                            }
-                        }
-                        else if (this.options.deleteAction) {
-                            this.__enableButton('.deleteButton');
-                        }
-                    }
-                    else { // view
-                        if (this.options.parentData
-                                && !this.options.childData) {
-                            $parentTable.show();
-                            $childTable.hide();
-                        }
-                        else {
-                            $parentTable.hide();
-                            $childTable.show();
-                        }
-
-                        // Child-Widgets disablen
-    
-                        $childWidgets.prop('disabled',true);
-                        $childWidgets.removeClass('enabled');
-                        $childWidgets.addClass('disabled');
-
-                        // Buttons disablen
-    
-                        this.__disableButton('.saveButton');
-                        this.__disableButton('.copyButton');
-                        this.__disableButton('.deleteButton');
-                    }
-                }
-            });
-
-            $('#__ID__').inheritForm({
+            $('#__ID__').inheritanceForm({
                 title: '__TITLE__',
                 parentData: __PARENT_DATA__,
                 childData: __CHILD_DATA__,
@@ -568,7 +589,7 @@ sub html {
 
 =head1 VERSION
 
-1.082
+1.083
 
 =head1 AUTHOR
 
